package App::cpanoutdated::coro;
use 5.008001;
use strict;
use warnings;

our $VERSION = "0.05";

1;
__END__

=encoding utf-8

=head1 NAME

App::cpanoutdated::coro - faster C<cpan-outdated>

=head1 DESCRIPTION

see L<cpan-outdated-coro>

=head1 LICENSE

Copyright (C) 2014 KPEE.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

KPEE E<lt>kpee.cpanx@gmail.comE<gt>

=cut
